@@ -46,7 +46,8 @@ class CutPdfPic(QWidget, Ui_CutPdfPic):
     getOnePicBarSignal = pyqtSignal(float)
     WidgetColorSignal = pyqtSignal(str)
     def __init__(self, communication=None, token = ""):
-        super(CutPdfPic, self).__init__(communication)
+        # super(CutPdfPic, self).__init__(communication)
+        super().__init__(communication)
         self.setupUi(self)
         self.UiInit()
         self.communication = communication
